Properties Methods Events Config Options Direct Link

# Class Ext.ux.form.MultiSelect

Package: | Ext.ux.form
Defined In: | MultiSelect.js
Class: | MultiSelect
Extends: | Object

A control that allows selection and form submission of multiple list items.

## Config Options

Config Options | Defined By
--- | ---
| allowBlank : Boolean False to require at least one item in the list to be selected, true to allow no selection (defaults to true). | MultiSelect
| allowBlank : Boolean False to require at least one item in the list to be selected, true to allow no selection (defaults to true). | MultiSelect
| appendOnly : String True if the list should only allow append drops when drag/drop is enabled (use for lists which are sorted, defaults t... True if the list should only allow append drops when drag/drop is enabled (use for lists which are sorted, defaults to false). | MultiSelect
| appendOnly : String True if the list should only allow append drops when drag/drop is enabled (use for lists which are sorted, defaults t... True if the list should only allow append drops when drag/drop is enabled (use for lists which are sorted, defaults to false). | MultiSelect
| blankText : String Default text displayed when the control contains no items (defaults to the same value as Ext.form.TextField.blankText... Default text displayed when the control contains no items (defaults to the same value as Ext.form.TextField.blankText. | MultiSelect
| blankText : String Default text displayed when the control contains no items (defaults to the same value as Ext.form.TextField.blankText... Default text displayed when the control contains no items (defaults to the same value as Ext.form.TextField.blankText. | MultiSelect
| ddReorder : Boolean Whether the items in the MultiSelect list are drag/drop reorderable (defaults to false). | MultiSelect
| ddReorder : Boolean Whether the items in the MultiSelect list are drag/drop reorderable (defaults to false). | MultiSelect
| delimiter : String The string used to delimit between items when set or returned as a string of values (defaults to ','). | MultiSelect
| delimiter : String The string used to delimit between items when set or returned as a string of values (defaults to ','). | MultiSelect
| displayField : String/Number Name/Index of the desired display field in the dataset (defaults to 0). | MultiSelect
| displayField : String/Number Name/Index of the desired display field in the dataset (defaults to 0). | MultiSelect
| dragGroup : String/Array The ddgroup name(s) for the MultiSelect DragZone (defaults to undefined). | MultiSelect
| dragGroup : String/Array The ddgroup name(s) for the MultiSelect DragZone (defaults to undefined). | MultiSelect
| dropGroup : String/Array The ddgroup name(s) for the MultiSelect DropZone (defaults to undefined). | MultiSelect
| dropGroup : String/Array The ddgroup name(s) for the MultiSelect DropZone (defaults to undefined). | MultiSelect
| height : Number Height in pixels of the control (defaults to 100). | MultiSelect
| height : Number Height in pixels of the control (defaults to 100). | MultiSelect
| legend : String Wraps the object with a fieldset and specified legend. | MultiSelect
| legend : String Wraps the object with a fieldset and specified legend. | MultiSelect
| maxSelections : Number Maximum number of selections allowed (defaults to Number.MAX_VALUE). | MultiSelect
| maxSelections : Number Maximum number of selections allowed (defaults to Number.MAX_VALUE). | MultiSelect
| maxSelectionsText : String Validation message displayed when maxSelections is not met (defaults to 'Maximum {0} item(s) allowed'). The {0} toke... Validation message displayed when maxSelections is not met (defaults to 'Maximum {0} item(s) allowed'). The {0} token will be replaced by the value of maxSelections. | MultiSelect
| maxSelectionsText : String Validation message displayed when maxSelections is not met (defaults to 'Maximum {0} item(s) allowed'). The {0} toke... Validation message displayed when maxSelections is not met (defaults to 'Maximum {0} item(s) allowed'). The {0} token will be replaced by the value of maxSelections. | MultiSelect
| minSelections : Number Minimum number of selections allowed (defaults to 0). | MultiSelect
| minSelections : Number Minimum number of selections allowed (defaults to 0). | MultiSelect
| minSelectionsText : String Validation message displayed when minSelections is not met (defaults to 'Minimum {0} item(s) required'). The {0} tok... Validation message displayed when minSelections is not met (defaults to 'Minimum {0} item(s) required'). The {0} token will be replaced by the value of minSelections. | MultiSelect
| minSelectionsText : String Validation message displayed when minSelections is not met (defaults to 'Minimum {0} item(s) required'). The {0} tok... Validation message displayed when minSelections is not met (defaults to 'Minimum {0} item(s) required'). The {0} token will be replaced by the value of minSelections. | MultiSelect
| store : Ext.data.Store/Array The data source to which this MultiSelect is bound (defaults to undefined). Acceptable values for this property are: ... The data source to which this MultiSelect is bound (defaults to `undefined`). Acceptable values for this property are: any Store subclass an Array : Arrays will be converted to a Ext.data.ArrayStore internally. 1-dimensional array : (e.g., `['Foo','Bar']`) A 1-dimensional array will automatically be expanded (each array item will be the combo value and text) 2-dimensional array : (e.g., `[['f','Foo'],['b','Bar']]`) For a multi-dimensional array, the value in index 0 of each item will be assumed to be the combo value, while the value at index 1 is assumed to be the combo text. | MultiSelect
| store : Ext.data.Store/Array The data source to which this MultiSelect is bound (defaults to undefined). Acceptable values for this property are: ... The data source to which this MultiSelect is bound (defaults to `undefined`). Acceptable values for this property are: any Store subclass an Array : Arrays will be converted to a Ext.data.ArrayStore internally. 1-dimensional array : (e.g., `['Foo','Bar']`) A 1-dimensional array will automatically be expanded (each array item will be the combo value and text) 2-dimensional array : (e.g., `[['f','Foo'],['b','Bar']]`) For a multi-dimensional array, the value in index 0 of each item will be assumed to be the combo value, while the value at index 1 is assumed to be the combo text. | MultiSelect
| tbar : Object/Array The top toolbar of the control. This can be a Ext.Toolbar object, a toolbar config, or an array of buttons/button con... The top toolbar of the control. This can be a Ext.Toolbar object, a toolbar config, or an array of buttons/button configs to be added to the toolbar. | MultiSelect
| tbar : Object/Array The top toolbar of the control. This can be a Ext.Toolbar object, a toolbar config, or an array of buttons/button con... The top toolbar of the control. This can be a Ext.Toolbar object, a toolbar config, or an array of buttons/button configs to be added to the toolbar. | MultiSelect
| valueField : String/Number Name/Index of the desired value field in the dataset (defaults to 1). | MultiSelect
| valueField : String/Number Name/Index of the desired value field in the dataset (defaults to 1). | MultiSelect
| view : Ext.ListView The Ext.ListView used to render the multiselect list. | MultiSelect
| view : Ext.ListView The Ext.ListView used to render the multiselect list. | MultiSelect
| width : Number Width in pixels of the control (defaults to 100). | MultiSelect
| width : Number Width in pixels of the control (defaults to 100). | MultiSelect

## Public Properties

This class has no public properties.

## Public Methods

Method | Defined By
--- | ---
| MultiSelect( `Object config` ) Create a new MultiSelect Create a new MultiSelect Parameters: `config` : Object Configuration options Returns: void | MultiSelect
| getTargetFromEvent() : void Part of the Ext.dd.DropZone interface. If no target node is found, the whole Element becomes the target, and this cau... Part of the Ext.dd.DropZone interface. If no target node is found, the whole Element becomes the target, and this causes the drop gesture to append. Parameters: None. Returns: void | MultiSelect
| getValue() : Array Returns an array of data values for the selected items in the list. The values will be separated by delimiter. Returns an array of data values for the selected items in the list. The values will be separated by delimiter. Parameters: None. Returns: `Array` value An array of string data values | MultiSelect
| setValue( `String/Array values` ) : void Sets a delimited string (using delimiter) or array of data values into the list. Sets a delimited string (using delimiter) or array of data values into the list. Parameters: `values` : String/Array The values to set Returns: void | MultiSelect

## Public Events

This class has no public events.